<?php
/*
Plugin Name: To Do List
Plugin URI: http://gwycon.com/to-do-list/
Description: Keep track of your daily tasks and activities. Create a to-do list for every user, so no excuse to remember that important post, or page. From v1.3, you can now use TinyMCE editor to format your list!
Version: 1.3
Author: David Gwyer
Author URI: http://www.gwycon.com/
*/

/*
    Copyright 2009 David Gwyer (email : d.v.gwyer(at)gwycon.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*

Plugin to do:

- need to have a drop down list of lists for admin.
- have an editor option db entry for each list (as admin can view/edit other lists, it is not a case that the author is always the current user).
- delete all users options if plugin deactivated (have an options page to do this). loop through all the current users, and delte option for each user.
- Also, I will add a facility for administrators only to view/edit any to do list. This would be useful for administrators to insert items on other peoples lists that need doing without having to send e-mails etc. everything would be self contained. Maybe do this so that text from admin to someone elses to do list gets highlighted in red (maybe have a CSS expand panel that has an option to turn this off so it is not highlighted, or to format it further (bold) etc.), think about having options only changeable if a user has admin privileges?
- If you are admin then have option to add a common block of text to any/all users. 
- What about making it a richer text box that allows web links, and formatted text etc. 
- do a new screenshot for plugin
*/

/* --------------------------------- */
/* ADMIN INTERFACE - START */ 
/* --------------------------------- */
add_action('admin_menu', 'gc_todo_admin_actions');
add_action('plugins_loaded', 'gc_todo_install' );
add_action('wp_dashboard_setup', 'to_do_list_add_dashboard_widgets' ); // Add UI to dashboard
add_filter('admin_head','ShowTinyMCE');
add_filter( 'tiny_mce_before_init', 'my_change_mce_settings' );

function my_change_mce_settings( $init_array ) {
	$init_array['width'] = "100%";
	$init_array['theme'] = 'advanced';
	$init_array['theme_advanced_buttons1'] = "bold,italic,underline,|,justifyleft,justifycenter,justifyright,justifyfull,cut,copy,paste,bullist,numlist";
	$init_array['theme_advanced_buttons2'] = "undo,redo,spellchecker,sub,sup,|,link,unlink,forecolor,backcolor,blockquote";
	$init_array['theme_advanced_buttons3'] = "formatselect,fontselect,fontsizeselect";
	$init_array['theme_advanced_resizing'] = true;
	//$init_array['theme_advanced_buttons1'] = "bold, italic";
	return $init_array;
}

function ShowTinyMCE() {
	// conditions here
	wp_enqueue_script( 'common' );
	wp_enqueue_script( 'jquery-color' );
	wp_print_scripts('editor');
	if (function_exists('add_thickbox')) add_thickbox();
	wp_print_scripts('media-upload');
	if (function_exists('wp_tiny_mce')) wp_tiny_mce();
	wp_admin_css();
	wp_enqueue_script('utils');
	do_action("admin_print_styles-post-php");
	do_action('admin_print_styles');
}

function gc_todo_admin_actions() {
 add_action( "admin_print_scripts", 'todo_load_scripts' );
}

function todo_load_scripts(){
    $file_url = WP_PLUGIN_URL.'/to-do-list';
	wp_enqueue_script('todo_functions', $file_url.'/todo_functions.js');
	echo "<link rel='stylesheet' href='$file_url/todo_style.css' type='text/css' />\n";
}

function gc_todo_install(){ // initialisation tasks
 global $user_ID;
 get_currentuserinfo();
 // only add an option if a valid $user_ID is returned
 // (i.e. not if a user has just logged out)
 if($user_ID || !$user_ID==''){
  $user = wp_get_current_user();
  $default_todo_list = "Hi $user->first_name, and thank you for installing the 'To Do List' WordPress Plug-in. I hope you find it useful, and please let us know any comments and suggestion you may have at info@gwycon.com.\r\n\r\nNow, delete this place holder text and get started on your own to do list right away! :-)";
  // if current user is has not list in db then create one with default text
  if(get_option("todo-$user_ID" == "") || !get_option("todo-$user_ID")){
   // echo 'No db entry found, writing new value.';
   add_option("todo-$user_ID", $default_todo_list);
  } else {
   // echo 'Entry exists.';
  }
  if(get_option('chk_toggle_editor' == '') || !get_option('chk_toggle_editor')){
   // echo 'No db entry found, writing new value.';
   add_option('chk_toggle_editor', 'off');
  } else {
   // echo 'Entry exists.';
  }
 }
}

function to_do_list_add_dashboard_widgets() {
	wp_add_dashboard_widget('to_do_list', 'To Do List', 'to_do_list_dashboard_widget_function');	
} 

/* --------------------------------- */
/* ADMIN INTERFACE - END */ 
/* --------------------------------- */

/* --------------------------------- */
/* PLUGIN CODE - START */
/* --------------------------------- */
function to_do_list_dashboard_widget_function() {
  include('todo_adminUI.php');
} 

// Create the function used in the action hook
function todo_user_deleted($id) {
	delete_option("todo-$id");
} 

add_action('delete_user', 'todo_user_deleted');
/* --------------------------------- */
/* PLUGIN CODE - END */
/* --------------------------------- */


/* --------------------------------- */
/* INTERNATIONALISATION CODE - START */
/* --------------------------------- */
function todo_init() {
  load_plugin_textdomain('todo_domain', 'wp-content/plugins/to-do-list/i18n');
}

add_action('init', 'todo_init');
/* --------------------------------- */
/* INTERNATIONALISATION CODE - END */
/* --------------------------------- */

?>